@@ -181,8 +181,10 @@ class WebPublisher(Publisher):
         return self.__send_request(data)
 
     def __send_request(self, data):
-        headers = { 'Content-Type': 'application/json' }
-        data['secret'] = self.secret
+        headers = {
+            'Content-Type': 'application/json',
+            'x-secret-key': self.secret  # Add the secret to the headers
+        }
         res = requests.post(self.url, headers=headers, json=data)
         res.raise_for_status()
         return res
@@ -191,7 +193,7 @@ class WebPublisher(Publisher):
         if others is None:
             others = {}
         data.update(others)
-        return sorted_data
+        return data
 
 
 if __name__ == "__main__":
